==> oci-java-sdk-shaded-full-3.40.0-sources.jar: com/oracle/bmc/jms/model/WorkItemDetails.java <==
/**
 * Copyright (c) 2016, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.jms.model;

/**
 * The minimum details of a work item. <br>
 * Note: Objects should always be created or deserialized using the {@link Builder}. This model
 * distinguishes fields that are {@code null} because they are unset from fields that are explicitly
 * set to {@code null}. This is done in the setter methods of the {@link Builder}, which maintain a
 * set of all explicitly set fields called {@link Builder#__explicitlySet__}. The {@link
 * #hashCode()} and {@link #equals(Object)} methods are implemented to take the explicitly set
 * fields into account. The constructor, on the other hand, does not take the explicitly set fields
 * into account (since the constructor cannot distinguish explicit {@code null} from unset {@code
 * null}).
 */
@jakarta.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20210610")
@com.fasterxml.jackson.annotation.JsonTypeInfo(
        use = com.fasterxml.jackson.annotation.JsonTypeInfo.Id.NAME,
        include = com.fasterxml.jackson.annotation.JsonTypeInfo.As.PROPERTY,
        property = "kind",
        defaultImpl = WorkItemDetails.class)
@com.fasterxml.jackson.annotation.JsonSubTypes({
    @com.fasterxml.jackson.annotation.JsonSubTypes.Type(
            value = LcmWorkItemDetails.class,
            name = "LCM"),
    @com.fasterxml.jackson.annotation.JsonSubTypes.Type(
            value = BasicWorkItemDetails.class,
            name = "BASIC"),
    @com.fasterxml.jackson.annotation.JsonSubTypes.Type(
            value = ApplicationWorkItemDetails.class,
            name = "APPLICATION")
})
@com.fasterxml.jackson.annotation.JsonFilter(
        com.oracle.bmc.http.client.internal.ExplicitlySetBmcModel.EXPLICITLY_SET_FILTER_NAME)
public class WorkItemDetails extends com.oracle.bmc.http.client.internal.ExplicitlySetBmcModel {
    @Deprecated
    @java.beans.ConstructorProperties({"workItemType"})
    protected WorkItemDetails(WorkItemType workItemType) {
        super();
        this.workItemType = workItemType;
    }

    /** The work item type. */
    @com.fasterxml.jackson.annotation.JsonProperty("workItemType")
    private final WorkItemType workItemType;

    /**
     * The work item type.
     *
     * @return the value
     */
    public WorkItemType getWorkItemType() {
        return workItemType;
    }

    @Override
    public String toString() {
        return this.toString(true);
    }

    /**
     * Return a string representation of the object.
     *
     * @param includeByteArrayContents true to include the full contents of byte arrays
     * @return string representation
     */
    public String toString(boolean includeByteArrayContents) {
        java.lang.StringBuilder sb = new java.lang.StringBuilder();
        sb.append("WorkItemDetails(");
        sb.append("super=").append(super.toString());
        sb.append("workItemType=").append(String.valueOf(this.workItemType));
        sb.append(")");
        return sb.toString();
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof WorkItemDetails)) {
            return false;
        }

        WorkItemDetails other = (WorkItemDetails) o;
        return java.util.Objects.equals(this.workItemType, other.workItemType)
                && super.equals(other);
    }

    @Override
    public int hashCode() {
        final int PRIME = 59;
        int result = 1;
        result = (result * PRIME) + (this.workItemType == null ? 43 : this.workItemType.hashCode());
        result = (result * PRIME) + super.hashCode();
        return result;
    }

    /** The kind of work item details. */
    public enum Kind implements com.oracle.bmc.http.internal.BmcEnum {
        Basic("BASIC"),
        Application("APPLICATION"),
        Lcm("LCM"),

        /**
         * This value is used if a service returns a value for this enum that is not recognized by
         * this version of the SDK.
         */
        UnknownEnumValue(null);

        private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(Kind.class);

        private final String value;
        private static java.util.Map<String, Kind> map;

        static {
            map = new java.util.HashMap<>();
            for (Kind v : Kind.values()) {
                if (v != UnknownEnumValue) {
                    map.put(v.getValue(), v);
                }
            }
        }

        Kind(String value) {
            this.value = value;
        }

        @com.fasterxml.jackson.annotation.JsonValue
        public String getValue() {
            return value;
        }

        @com.fasterxml.jackson.annotation.JsonCreator
        public static Kind create(String key) {
            if (map.containsKey(key)) {
                return map.get(key);
            }
            LOG.warn(
                    "Received unknown value '{}' for enum 'Kind', returning UnknownEnumValue", key);
            return UnknownEnumValue;
        }
    };
}

==> oci-java-sdk-shaded-full-3.48.0-sources.jar: com/oracle/bmc/jms/model/WorkItemDetails.java <==
/**
 * Copyright (c) 2016, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.jms.model;

/**
 * The minimum details of a work item. <br>
 * Note: Objects should always be created or deserialized using the {@link Builder}. This model
 * distinguishes fields that are {@code null} because they are unset from fields that are explicitly
 * set to {@code null}. This is done in the setter methods of the {@link Builder}, which maintain a
 * set of all explicitly set fields called {@link Builder#__explicitlySet__}. The {@link
 * #hashCode()} and {@link #equals(Object)} methods are implemented to take the explicitly set
 * fields into account. The constructor, on the other hand, does not take the explicitly set fields
 * into account (since the constructor cannot distinguish explicit {@code null} from unset {@code
 * null}).
 */
@jakarta.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20210610")
@com.fasterxml.jackson.annotation.JsonTypeInfo(
        use = com.fasterxml.jackson.annotation.JsonTypeInfo.Id.NAME,
        include = com.fasterxml.jackson.annotation.JsonTypeInfo.As.PROPERTY,
        property = "kind",
        defaultImpl = WorkItemDetails.class)
@com.fasterxml.jackson.annotation.JsonSubTypes({
    @com.fasterxml.jackson.annotation.JsonSubTypes.Type(
            value = DeployedApplicationWorkItemDetails.class,
            name = "DEPLOYED_APPLICATION"),
    @com.fasterxml.jackson.annotation.JsonSubTypes.Type(
            value = LcmWorkItemDetails.class,
            name = "LCM"),
    @com.fasterxml.jackson.annotation.JsonSubTypes.Type(
            value = BasicWorkItemDetails.class,
            name = "BASIC"),
    @com.fasterxml.jackson.annotation.JsonSubTypes.Type(
            value = ApplicationWorkItemDetails.class,
            name = "APPLICATION")
})
@com.fasterxml.jackson.annotation.JsonFilter(
        com.oracle.bmc.http.client.internal.ExplicitlySetBmcModel.EXPLICITLY_SET_FILTER_NAME)
public class WorkItemDetails extends com.oracle.bmc.http.client.internal.ExplicitlySetBmcModel {
    @Deprecated
    @java.beans.ConstructorProperties({"workItemType"})
    protected WorkItemDetails(WorkItemType workItemType) {
        super();
        this.workItemType = workItemType;
    }

    /** The work item type. */
    @com.fasterxml.jackson.annotation.JsonProperty("workItemType")
    private final WorkItemType workItemType;

    /**
     * The work item type.
     *
     * @return the value
     */
    public WorkItemType getWorkItemType() {
        return workItemType;
    }

    @Override
    public String toString() {
        return this.toString(true);
    }

    /**
     * Return a string representation of the object.
     *
     * @param includeByteArrayContents true to include the full contents of byte arrays
     * @return string representation
     */
    public String toString(boolean includeByteArrayContents) {
        java.lang.StringBuilder sb = new java.lang.StringBuilder();
        sb.append("WorkItemDetails(");
        sb.append("super=").append(super.toString());
        sb.append("workItemType=").append(String.valueOf(this.workItemType));
        sb.append(")");
        return sb.toString();
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof WorkItemDetails)) {
            return false;
        }

        WorkItemDetails other = (WorkItemDetails) o;
        return java.util.Objects.equals(this.workItemType, other.workItemType)
                && super.equals(other);
    }

    @Override
    public int hashCode() {
        final int PRIME = 59;
        int result = 1;
        result = (result * PRIME) + (this.workItemType == null ? 43 : this.workItemType.hashCode());
        result = (result * PRIME) + super.hashCode();
        return result;
    }

    /** The kind of work item details. */
    public enum Kind implements com.oracle.bmc.http.internal.BmcEnum {
        Basic("BASIC"),
        Application("APPLICATION"),
        Lcm("LCM"),
        DeployedApplication("DEPLOYED_APPLICATION"),

        /**
         * This value is used if a service returns a value for this enum that is not recognized by
         * this version of the SDK.
         */
        UnknownEnumValue(null);

        private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(Kind.class);

        private final String value;
        private static java.util.Map<String, Kind> map;

        static {
            map = new java.util.HashMap<>();
            for (Kind v : Kind.values()) {
                if (v != UnknownEnumValue) {
                    map.put(v.getValue(), v);
                }
            }
        }

        Kind(String value) {
            this.value = value;
        }

        @com.fasterxml.jackson.annotation.JsonValue
        public String getValue() {
            return value;
        }

        @com.fasterxml.jackson.annotation.JsonCreator
        public static Kind create(String key) {
            if (map.containsKey(key)) {
                return map.get(key);
            }
            LOG.warn(
                    "Received unknown value '{}' for enum 'Kind', returning UnknownEnumValue", key);
            return UnknownEnumValue;
        }
    };
}
